@@ -5,5 +5,5 @@ import cssutils
 
 cssText = codecs.open('../sheets/cases.css', encoding='css').read()
 sheet = cssutils.parseString(cssText)
-print sheet
-print sheet.cssText
\ No newline at end of file
+print(sheet)
+print(sheet.cssText)
\ No newline at end of file
