@@ -1,12 +1,12 @@
-import logging, StringIO
+import logging, io
 
 EXPOUT = ""
-EXPERR = u"Property: Unknown Property name. [1:5: x]\nHTTPError opening url=http://cthedot.de/x: 404 Not Found\nCSSImportRule: While processing imported style sheet href=http://cthedot.de/x: IOError('Cannot read Stylesheet.',)\nCSSStylesheet: CSSImportRule not allowed here. [1:13: @import]\n"
+EXPERR = "Property: Unknown Property name. [1:5: x]\nHTTPError opening url=http://cthedot.de/x: 404 Not Found\nCSSImportRule: While processing imported style sheet href=http://cthedot.de/x: IOError('Cannot read Stylesheet.',)\nCSSStylesheet: CSSImportRule not allowed here. [1:13: @import]\n"
 
 def main():
     import cssutils
 
-    mylog = StringIO.StringIO()
+    mylog = io.StringIO()
     h = logging.StreamHandler(mylog)
     h.setFormatter(logging.Formatter('%(levelname)s    %(message)s'))
     #cssutils.log.addHandler(h)
