@@ -7,12 +7,35 @@ and for debugging also in @title attributes.
 
 adds css as text to html
 """
+from pprint import pprint
 import codecs
-import webbrowser
 import cssutils
-from lxml import etree
-from lxml.builder import E
-from lxml.cssselect import CSSSelector
+import os
+import sys
+import webbrowser
+
+# lxml egg may be in a lib dir below this file (not in SVN though)
+sys.path.append(os.path.join(os.path.dirname(__file__), 'lib'))
+try:
+    import pkg_resources
+    pkg_resources.require('lxml')
+except pkg_resources.DistributionNotFound as e:
+    pass
+
+try:
+    from lxml import etree
+    from lxml.builder import E
+    from lxml.cssselect import CSSSelector
+except ImportError as e:
+    print('You need lxml for this example:', e)
+    sys.exit(1)
+
+
+def log(level, *msg):
+    """print '%s- %s' % (level * '\t ',
+                      ' '.join((str(m) for m in msg)))"""
+                      
+    
 
 def getDocument(html, css=None):
     """
@@ -63,38 +86,51 @@ def getView(document, css, media='all', name=None,
     rules = (rule for rule in sheet if rule.type == rule.STYLE_RULE)    
     for rule in rules:
         for selector in rule.selectorList:
-            
+            log(0, 'SELECTOR', selector.selectorText)
             # TODO: make this a callback to be able to use other stuff than lxml
             cssselector = CSSSelector(selector.selectorText)
             matching = cssselector.evaluate(document)
             for element in matching:
-                # add styles for all matching DOM elements
-                if element not in view:
-                    # add initial
-                    view[element] = cssutils.css.CSSStyleDeclaration()
-                    specificities[element] = {}                    
-                    # add inline styles if present
-                    inlinestyle = styleCallback(element)
-                    if inlinestyle:
-                        for p in inlinestyle:
-                            # set inline style specificity
-                            view[element].setProperty(p)
-                            specificities[element][p.name] = (1,0,0,0)
-                                                        
-                for p in rule.style:
-                    # update styles
-                    if p not in view[element]:
-                        view[element].setProperty(p)
-                        specificities[element][p.name] = selector.specificity
-                    else:
-                        sameprio = (p.priority == 
-                                    view[element].getPropertyPriority(p.name))
-                        if not sameprio and bool(p.priority) or (
-                           sameprio and selector.specificity >= 
-                                        specificities[element][p.name]):
-                            # later, more specific or higher prio 
-                            view[element].setProperty(p)              
-
+                #if element.tag in ('div',):
+                    # add styles for all matching DOM elements
+                    log(1, 'ELEMENT', id(element), element.text)
+                    
+                    if element not in view:    
+                        # add initial empty style declatation
+                        view[element] = cssutils.css.CSSStyleDeclaration()
+                        specificities[element] = {}                    
+                        
+                        # and add inline @style if present
+                        inlinestyle = styleCallback(element)
+                        if inlinestyle:
+                            for p in inlinestyle:
+                                # set inline style specificity
+                                view[element].setProperty(p)
+                                specificities[element][p.name] = (1,0,0,0)
+                                                            
+                    for p in rule.style:
+                        # update style declaration
+                        if p not in view[element]:
+                            # setProperty needs a new Property object and
+                            # MUST NOT reuse the existing Property
+                            # which would be the same for all elements!
+                            # see Issue #23
+                            view[element].setProperty(p.name, p.value, p.priority)
+                            specificities[element][p.name] = selector.specificity
+                            log(2, view[element].getProperty('color'))
+                            
+                        else:
+                            log(2, view[element].getProperty('color'))
+                            sameprio = (p.priority == 
+                                        view[element].getPropertyPriority(p.name))
+                            if not sameprio and bool(p.priority) or (
+                               sameprio and selector.specificity >= 
+                                            specificities[element][p.name]):
+                                # later, more specific or higher prio 
+                                view[element].setProperty(p.name, p.value, p.priority)
+                    
+                   
+    #pprint(view)
     return view                        
 
 def render2style(document, view):
@@ -102,8 +138,8 @@ def render2style(document, view):
     - add style into @style attribute
     - add style into @title attribute (for debugging)
     """
-    for element, style in view.items():
-        v = style.getCssText(separator=u'')
+    for element, style in list(view.items()):
+        v = style.getCssText(separator='')
         element.set('style', v)
         element.set('title', v)
 
@@ -118,8 +154,8 @@ def render2content(document, view, css):
     e = etree.Element('style', {'type': 'text/css'})
     e.text = css
     document.find('head').append(e)
-    for element, style in view.items():
-        v = style.getCssText(separator=u'')
+    for element, style in list(view.items()):
+        v = style.getCssText(separator='')
         element.text = v
 
 def show(text, name, encoding='utf-8'):
@@ -133,12 +169,16 @@ def main():
     tpl = '''<html><head><title>style test</title></head><body>%s</body></html>'''
     html = tpl % '''
             <h1>Style example 1</h1>
-            <p>simple p</p>
-            <p style="color: red;">p with inline style: "color: red"</p>
-            <p id="x" style="color: red;">p#x with inline style: "color: red"
-                but see a#x!</p>
+            <p>&lt;p></p>
+            <p style="color: red;">&lt;p> with inline style: "color: red"</p>
+            <p id="x" style="color: red;">p#x with inline style: "color: red"</p>
+            <div>a &lt;div> green?</div>
+            <div id="y">#y pink?</div>
         '''
-    css = '''
+    css = r'''
+        * {
+            margin: 0;
+            }
         body {
             color: blue !important;
             font: normal 100% sans-serif;
@@ -150,6 +190,13 @@ def main():
         p#x {
             color: black !important;
         }
+        div {
+            color: green;
+            font-size: 1.5em;
+            }
+        #y {
+            color: #f0f;
+            }
         .cssutils {
             font: 1em "Lucida Console", monospace;
             border: 1px outset;
